aboutsummaryrefslogtreecommitdiffstats
path: root/examples/tutorials/gettingStartedQml/filedialog/dialogPlugin.h
diff options
context:
space:
mode:
Diffstat (limited to 'examples/tutorials/gettingStartedQml/filedialog/dialogPlugin.h')
-rw-r--r--examples/tutorials/gettingStartedQml/filedialog/dialogPlugin.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/examples/tutorials/gettingStartedQml/filedialog/dialogPlugin.h b/examples/tutorials/gettingStartedQml/filedialog/dialogPlugin.h
index 03bdc1a6e4..1aed6abc8e 100644
--- a/examples/tutorials/gettingStartedQml/filedialog/dialogPlugin.h
+++ b/examples/tutorials/gettingStartedQml/filedialog/dialogPlugin.h
@@ -3,7 +3,7 @@
** Copyright (C) 2012 Nokia Corporation and/or its subsidiary(-ies).
** Contact: http://www.qt-project.org/
**
-** This file is part of the QtDeclarative module of the Qt Toolkit.
+** This file is part of the QtQml module of the Qt Toolkit.
**
** $QT_BEGIN_LICENSE:BSD$
** You may use this file under the terms of the BSD license as follows:
@@ -41,14 +41,14 @@
#ifndef DIALOGPLUGIN_H
#define DIALOGPLUGIN_H
-#include <QtDeclarative/QDeclarativeExtensionPlugin>
+#include <QtQml/QQmlExtensionPlugin>
-class DialogPlugin : public QDeclarativeExtensionPlugin
+class DialogPlugin : public QQmlExtensionPlugin
{
Q_OBJECT
public:
//registerTypes is inherited from QDeclarativeExtensionPlugin
void registerTypes(const char *uri);
};
@@ -41,14 +41,14 @@
Q_OBJECT
public:
- //registerTypes is inherited from QDeclarativeExtensionPlugin
+ //registerTypes is inherited from QQmlExtensionPlugin
void registerTypes(const char *uri);
};